@@ -29,6 +29,8 @@
 #include <fcntl.h> // open
 #include <sys/types.h> // uid_t
 
+using namespace Qt::StringLiterals;
+
 KCONFIGCORE_EXPORT bool kde_kiosk_exception = false; // flag to disable kiosk restrictions
 
 static QByteArray lookup(const KConfigIniBackend::BufferFragment fragment, QHash<KConfigIniBackend::BufferFragment, QByteArray> *cache)
@@ -442,7 +444,9 @@ bool KConfigIniBackend::writeConfig(const QByteArray &locale, KEntryMap &entryMa
     // so write it out to disk
 
     // check if file exists
-    QFile::Permissions fileMode = QFile::ReadUser | QFile::WriteUser;
+    QFile::Permissions fileMode = filePath().startsWith(u"/etc/xdg/"_s) ? QFile::ReadUser | QFile::WriteUser | QFile::ReadGroup | QFile::ReadOther //
+                                                                        : QFile::ReadUser | QFile::WriteUser;
+
     bool createNew = true;
 
     QFileInfo fi(filePath());
